#===============================================================================
# Name   : tcmm_sk_deb
# Author : J.C.Faria
# Date   : 2023-06-15 08:30:27
# Aim    : Simular experimentos nos delineamentos DIC, DBC e DQL no R
#          e agrupar as médias pelo algoritmo de Scott-Knott
# Mail   : <<<joseclaudio.faria@gmail.com>>>
#===============================================================================

#. Carregando pacotes necessários
#.. gexp
#install.packages('gexp')
library(gexp)

#.. ScottKnott
#install.packages('ScottKnott')
library(ScottKnott)

#.. TukeyC
#install.packages('TukeyC')
library(TukeyC)

#. Gerando e analisando experimentos
#.. ___DIC___
#... Simulação
set.seed(2019)
dic <- gexp(mu=5,
            r=4,
            fe=list(1:4),
            fl=list(X=paste('x',
                            1:4,
                            sep=''))
            )

summary(dic)

par(mfrow=c(1, 1))
plot(dic,
     main='DIC')

#... Análise
# ANOVA
av_dic <- aov(Y1 ~ X,
              dic$dfm)

summary(av_dic)

## Análise de resíduos (opcional)
#par(mfrow=c(2, 2))
#plot(av_dic)

sk_dic <- SK(av_dic)

summary(sk_dic)

par(mfrow=c(1, 1))
plot(sk_dic,
     main='',
     ylab='Y1',
     xlab='X',
     disp='mm')

# Comparando com teste de Tukey
tk_b <- TukeyC(av_dic,
               sig.lev=5/100)

summary(tk_b)

par(mfrow=c(1, 1))
plot(tk_b,
     disp='mm')

#.. ___DBC___
#... Simulação
set.seed(2019)
dbc <- gexp(mu=5,
            r=2, # repetição do tratamento dentro do bloco
            fe=list(f1=c(5, 1, 1, 1)),
            fl=list(X=paste('x',
                            1:4,
                            sep='')),
            blke=c(1, 2, 3),
            blkl=list(BLO=paste('b',
                                1:3,
                                sep='')),
            round=1,
            design='RCBD'
           )

summary(dbc)

par(mfrow=c(1, 1))
plot(dbc,
     main='DBC')


#... Análise
# ANOVA
av_dbc <- aov(Y1 ~ BLO + X,
              dbc$dfm)

summary(av_dbc)

## Análise de resíduos (opcional)
#par(mfrow=c(2, 2))
#plot(av_dbc)

# TCMM
# Efeito dos blocos
sk_blo <- SK(av_dbc,
             which='BLO')

summary(sk_blo)

# Ordenando as médias dos blocos em ordem decrescente para boxplot
bym_blo <- with(dbc$dfm,
                reorder(BLO,
                        -Y1,
                        mean))

levels(bym_blo)

# Vizualizando efeito do bloco
par(mfrow=c(2, 1))
boxplot(Y1 ~ bym_blo,
        dbc$dfm,
        names=levels(bym_blo),
        ylab='',
        xlab='')

plot(sk_blo,
     ylab='Y1',
     xlab='BLO')

# Efeito dos tratamentos
sk_x <- SK(av_dbc,
           which='X')

summary(sk_x)

# Ordenando as médias dos tratamentos em ordem decrescente para boxplot
bym_x <- with(dbc$dfm,
              reorder(X,
                      -Y1,
                      mean))

levels(bym_x)

# Vizualizando efeito do tratamento
par(mfrow=c(2, 1))
boxplot(Y1 ~ bym_x,
        dbc$dfm,
        names=levels(bym_x),
        ylab='',
        xlab='')

plot(sk_x,
     main='',
     ylab='Y1',
     xlab='X')


#.. ___DQL___
#... Simulação
set.seed(2019)
dql <- gexp(mu=10,
            r=1,
            fe=list(f1=c(1, 1, 2, 2, 10)),
            fl=list(X=paste('x',
                            1:5,
                            sep='')),
            rowe=c(1, 2, 3, 4, 5),
            cole=c(5, 4, 3, 2, 1),
            rowl=list(LIN=paste('l',
                                1:5,
                                sep='')),
            coll=list(COL=paste('c',
                                1:5,
                                sep='')),
            round=1,
            design='LSD'
           )

summary(dql)

par(mfrow=c(1, 1))
plot(dql,
     main='DQL')

#... Análise
# ANOVA
av_dql <- aov(Y1 ~ LIN + COL + X,
              dql$dfm)

summary(av_dql)

## Análise de resíduos (opcional)
#par(mfrow=c(2, 2))
#plot(av_dql)

# TCMM
# Efeito das linhas
sk_lin <- SK(av_dql,
             which='LIN')

summary(sk_lin)

# Efeito das colunas
sk_col <- SK(av_dql,
             which='COL')

summary(sk_col)

# Efeito dos tratamentos
sk_x <- SK(av_dql,
           which='X')

summary(sk_x)

# Visualizando os resultados do TCMM
par(mfrow=c(3, 1))

# Linha - LIN
plot(sk_lin,
     main='',
     ylab='',
     xlab='Linha',
     disp='mm')

# Coluna - COL
plot(sk_col,
     main='',
     ylab='',
     xlab='Coluna',
     disp='mm')

# Tratamento - X
plot(sk_x,
     main='',
     ylab='Y1',
     xlab='X',
     disp='mm')
